@@ -213,6 +213,7 @@ class FlowsClient(BaseClient):
         input_schema: Optional[Mapping[str, Any]] = None,
         validate_definition: bool = True,
         validate_input_schema: bool = True,
+        dry_run: bool = False,
         **kwargs,
     ) -> GlobusHTTPResponse:
         """Deploys a Flow definition to the Flows service, making the Flow
@@ -240,8 +241,8 @@ class FlowsClient(BaseClient):
         :param administered_by: A series of Globus identities which may update
             this Flow's definition
 
-        :param subscription_id: The Globus Subscription which will be used to make this
-        flow managed.
+        :param subscription_id: The Globus Subscription which will be used to
+            make this flow managed.
 
         :param input_schema: A mapping representing the JSONSchema used to
             validate input to this Flow. If not supplied, no validation will be
@@ -268,7 +269,10 @@ class FlowsClient(BaseClient):
         temp_body["input_schema"] = input_schema
         # Remove None / empty list items from the temp_body
         req_body = {k: v for k, v in temp_body.items() if v}
-        return self.post("/flows", req_body, **kwargs)
+        url = "/flows"
+        if dry_run:
+            url = "/flows/dry-run"
+        return self.post(url, req_body, **kwargs)
 
     def update_flow(
         self,
@@ -316,8 +320,8 @@ class FlowsClient(BaseClient):
         :param administered_by: A series of Globus identities which may update
             this Flow's definition
 
-        :param subscription_id: The Globus Subscription which will be used to make this
-        flow managed.
+        :param subscription_id: The Globus Subscription which will be used to
+            make this flow managed.
 
         :param input_schema: A mapping representing the JSONSchema used to
             validate input to this Flow. If not supplied, no validation will be
@@ -384,7 +388,7 @@ class FlowsClient(BaseClient):
             where the retrieving identity has at least one of the listed roles on
             each Flow
         :param marker: A pagination_token indicating the page of results to
-            return and how many entries to return. This is created by the Flow's
+            return and how many entries to return. This is created by the Flows
             service and returned by operations that support pagination.
         :param per_page: The number of results to return per page. If
             supplied a pagination_token, this parameter has no effect.
@@ -404,7 +408,7 @@ class FlowsClient(BaseClient):
         self.authorizer = self.flow_management_authorizer
         params = {}
         if roles is not None and len(roles) > 0:
-            params.update(dict(filter_roles=",".join(roles)))
+            params["filter_roles"] = ",".join(roles)
         if marker is not None:
             params["pagination_token"] = marker
         if per_page is not None and marker is None:
@@ -418,7 +422,7 @@ class FlowsClient(BaseClient):
             params["orderby"] = ",".join(builder)
         return self.get("/flows", params=params, **kwargs)
 
-    def delete_flow(self, flow_id: str, **kwargs):
+    def delete_flow(self, flow_id: str, **kwargs) -> GlobusHTTPResponse:
         """
         Remove a Flow definition and its metadata from the Flows service
 
@@ -461,6 +465,7 @@ class FlowsClient(BaseClient):
         flow_input: Mapping,
         manage_by: Optional[List[str]] = None,
         monitor_by: Optional[List[str]] = None,
+        dry_run: bool = False,
         **kwargs,
     ) -> GlobusHTTPResponse:
         """
@@ -493,7 +498,11 @@ class FlowsClient(BaseClient):
         authorizer = self._get_authorizer_for_flow(flow_id, flow_scope, kwargs)
         flow_url = f"{self.base_url}/flows/{flow_id}"
         ac = ActionClient.new_client(flow_url, authorizer)
-        return ac.run(flow_input, manage_by=manage_by, monitor_by=monitor_by, **kwargs)
+        if dry_run:
+            path = flow_url + "/dry-run"
+            return ac.run(flow_input, manage_by=manage_by, monitor_by=monitor_by, force_path=path, **kwargs)
+        else:
+            return ac.run(flow_input, manage_by=manage_by, monitor_by=monitor_by, **kwargs)
 
     def flow_action_status(
         self, flow_id: str, flow_scope: Optional[str], flow_action_id: str, **kwargs
@@ -593,6 +602,76 @@ class FlowsClient(BaseClient):
         ac = ActionClient.new_client(flow_url, authorizer)
         return ac.cancel(flow_action_id)
 
+    def enumerate_actions(
+        self,
+        roles: Optional[List[str]] = None,
+        statuses: Optional[List[str]] = None,
+        marker: Optional[str] = None,
+        per_page: Optional[int] = None,
+        filters: Optional[dict] = None,
+        orderings: Optional[dict] = None,
+        **kwargs,
+    ) -> GlobusHTTPResponse:
+        """
+        Retrieve a listing of Actions the caller has access to. This operation
+        requires the supplied Authorizer to have the RUN_STATUS_SCOPE.
+
+        :param roles:
+            A list of roles specifying the level of access you have
+            for a Flow. Valid values are:
+
+            - created_by
+            - visible_to
+            - runnable_by
+            - administered_by
+
+            Each value in the ``roles`` list is Or-ed to retrieve a listing of Flows
+            where the retrieving identity has at least one of the listed roles on
+            each Flow
+        :param statuses: A list of statuses used to filter the Actions that are
+            returned by the listing. Returned Actions are guaranteed to have one
+            of the specified ``statuses``. Valid values are:
+
+            - SUCCEEDED
+            - FAILED
+            - ACTIVE
+            - INACTIVE
+        :param marker: A pagination_token indicating the page of results to
+            return and how many entries to return. This is created by the Flows
+            service and returned by operations that support pagination.
+        :param per_page: The number of results to return per page. If
+            supplied a pagination_token, this parameter has no effect.
+        :param filters: A filtering criteria to apply to the resulting Flow
+            listing. The keys indicate the filter, the values indicate the
+            pattern to match. The returned data will be the result of a logical
+            AND between the filters. Patterns may be comma separated to produce
+            the result of a logical OR.
+        :param orderings: An ordering criteria to apply to the resulting
+            Flow listing. The keys indicate the field to order on, and
+            the value can be either ASC, for ascending order, or DESC, for
+            descending order. The first ordering criteria will be used to sort
+            the data, subsequent ordering criteria will be applied for ties.
+            Note: To ensure orderings are applied in the correct order, use an
+            OrderedDict if trying to apply multiple orderings.
+        """
+        params = {}
+        if roles is not None and len(roles) > 0:
+            params["filter_roles"] = ",".join(roles)
+        if statuses is not None and len(statuses) > 0:
+            params["filter_status"] = ",".join(statuses)
+        if marker is not None:
+            params["pagination_token"] = marker
+        if per_page is not None and marker is None:
+            params["per_page"] = str(per_page)
+        if filters is not None:
+            params.update(filters)
+        if orderings:
+            builder = []
+            for field, value in orderings.items():
+                builder.append(f"{field} {value}")
+            params["orderby"] = ",".join(builder)
+        return self.get(f"/runs", params=params, **kwargs)
+
     def list_flow_actions(
         self,
         flow_id: str,
@@ -633,7 +712,7 @@ class FlowsClient(BaseClient):
             - administered_by
 
         :param marker: A pagination_token indicating the page of results to
-            return and how many entries to return. This is created by the Flow's
+            return and how many entries to return. This is created by the Flows
             service and returned by operations that support pagination.
         :param per_page: The number of results to return per page. If
             supplied a pagination_token, this parameter has no effect.
@@ -657,9 +736,9 @@ class FlowsClient(BaseClient):
         """
         params = {}
         if statuses is not None and len(statuses) > 0:
-            params.update(dict(filter_status=",".join(statuses)))
+            params["filter_status"] = ",".join(statuses)
         if roles is not None and len(roles) > 0:
-            params.update(dict(filter_roles=",".join(roles)))
+            params["filter_roles"] = ",".join(roles)
         if marker is not None:
             params["pagination_token"] = marker
         if per_page is not None and marker is None:
@@ -708,7 +787,7 @@ class FlowsClient(BaseClient):
             in reverse-chronological order.
 
         :param marker: A pagination_token indicating the page of results to
-            return and how many entries to return. This is created by the Flow's
+            return and how many entries to return. This is created by the Flows
             service and returned by operations that support pagination.
         :param per_page: The number of results to return per page. If
             supplied a pagination_token, this parameter has no effect.
@@ -740,22 +819,21 @@ class FlowsClient(BaseClient):
         process.
 
         :param client_id: The client_id to associate with this FlowsClient.
-
         :param authorizer_callback: A callable which is capable of returning an
             authorizer for a particular Flow. The callback should accept three
             keyword-args: flow_url, flow_scope, client_id. Using some, all, or
             none of these args, the callback should return a GlobusAuthorizer
             which provides access to the targetted Flow.
-
         :param authorizer: The authorizer to use for validating requests to the
             Flows service. This authorizer is used when interacting with the
             Flow's service, it is not used for interactive with a particular
             flow. Therefore, this authorizer should grant consent to the
             MANAGE_FLOWS_SCOPE. For interacting with a particular flow, set the
             authorizer_callback parameter.
-
         :param base_url: The url at which the target Action Provider is
             located.
+        :param http_timeout: The amount of time to wait for connections to
+            the Action Provider to be made.
 
         **Examples**
             >>> def cli_authorizer_callback(**kwargs):
